# Jupyter Community Call 11/29

**Date:** November 29, 2022, at 7am Pacific (in your [timezone](https://arewemeetingyet.com/Los%20Angeles/2022-11-29/7:00/Jupyter%20Community%20Call))

[**Discourse**](https://discourse.jupyter.org/t/jupyter-community-calls/668)
[**Youtube**](https://youtu.be/GsOjIvV7ymY)

**Please note:**
- Community calls are recorded and posted to this [playlist](https://www.youtube.com/playlist?list=PLUrHeD2K9Cmkoamm4NjLmvXC4Y6E1o8SP)
- These notes will be recorded and posted [here](https://jupyter.readthedocs.io/en/latest/community/community-call-notes/index.html)
- Everyone present is held to the [Jupyter Code of Conduct](https://jupyter.org/conduct)

## Purpose

Think of it as a monthly, virtual JupyterCon. It’s a place to announce and share fun things happening in the Jupyter community.

For more discussion on the format of these calls, see the thread [here](https://discourse.jupyter.org/t/reviving-the-all-jupyter-team-meetings/423).

## Short reports, celebrations, shout-outs

There were no short reports this month.

## Agenda Items

* **Gabriela Vives** Present a usability study done on JupyterLab
* **Eric Gao** Jupyter+Apache DolphinsSheduler Demo
* **Nick Bollweg** [jupikchr](https://github.com/deathbeds/jupikchr): pikchr plain-text diagrams for JupyterLab, etc.

## Other Links Shared

This is a space to store links shared during community call discussions related to or separate from the agenda items.

- [jupyter/surveys](https://github.com/jupyter/surveys)
- [Jupyter community building committee](https://jupyter.org/governance/communitybuildingcommittee.html)
- [JupyterLite as a frontend for software forges - Jupyter Discourse](https://github.com/jupyterlite/jupyterlite/discussions/874)

## Attendees

|   Name   |           Institution     | GitHub Handle|
|----------|---------------------------|--------------|
|  Yuze Ma | Alibaba Cloud           | bobmayuze |
| Frederic Collonval| QuantStack | @fcollonval 
| Gabriela Vives         | QuantStack           |GabrielaVives 
|Matthew Seal|Noteable Inc|MSeal|
| Wayne Decatur|Upstate Medical University|fomightez |
|       Eric Gao      |   Jupyter+Apache DolphinsSheduler Demo         | EricGao888   |
|tonyfast          | unaffiliated            |  @tonyfast |
| Isabela Presedo-Floyd | Quansight Labs | @isabela-pf |

Plus 11 more.